@@ -20,7 +20,6 @@ from .task import (
     JOB_PENDING,
     REPROC,
     RERUN,
-    FAILED_NEEDS_REPROC,
     NEEDS_QA,
 )
 from . import utilities
@@ -493,7 +492,14 @@ class Processor_v3(object):
             raise AutoProcessorError(err)
 
         # Initialize command
-        command_txt = f'singularity {runexec} {SINGULARITY_BASEOPTS}'
+        if 'opts' in command:
+            # Get the user defined opts
+            _opts = command['opts']
+            # Prepend clean and contain
+            _opts = f'--contain --cleanenv {_opts}'
+            command_txt = f'singularity {runexec} {_opts}'
+        else:
+            command_txt = f'singularity {runexec} {SINGULARITY_BASEOPTS}'
 
         # Append extra options
         _extra = command.get('extraopts', None)
@@ -1119,7 +1125,7 @@ class Processor_v3(object):
 
                     # If requested, check for multiple matching scans in the list and only keep
                     # the first. Sort lowercase by alpha, on scan ID.
-                    if iv['keep_multis'] != 'all':
+                    if len(artefacts_by_input[i]) > 0 and iv['keep_multis'] != 'all':
                         scan_info = zip(
                             artefacts_by_input[i],
                             artefact_ids_by_input[i],
@@ -1235,32 +1241,38 @@ class Processor_v3(object):
         return final_matrix
 
     def _compare_to_existing(self, csess, parameter_matrix):
-        proc_type = self.proctype
-
         assessors = [[] for _ in range(len(parameter_matrix))]
 
+        # Get of list assessors that have already been 
+        # created on xnat for this processor/proctype
+        existing_assessors = []
         for casr in csess.assessors():
-            # Check for empty inputs. If ANY of the assessors on this session
-            # have an empty inputs, then we cannot determine which input sets
-            # need to be built. We refuse to do anything by returning
-            # an empty list.
-            inputs = casr.get_inputs()
-            if inputs is None:
-                LOGGER.warn('assessor with empty inputs field, cannot build processor for session' + casr.label())
-                return list()
-
+            # Check that proc type matches this processor
             try:
-                proc_type_matches = (casr.type() == proc_type)
+                proc_type_matches = (casr.type() == self.proctype)
+                if proc_type_matches:
+                    existing_assessors.append(casr)
             except:
                 LOGGER.warning(f'Unable to check match of {casr.label()} - ignoring')
                 continue
 
-            if proc_type_matches:
-                for pi, p in enumerate(parameter_matrix):
-                    if inputs == p:
-                        # BDB  6/5/21 do we ever have more than one assessor
-                        #             with the same set of inputs?
-                        assessors[pi].append(casr)
+        # Check for any missing inputs fields in the existing assessors
+        for casr in existing_assessors:
+            # Check for empty inputs. If ANY of the assessors on this session
+            # have an empty inputs, then we cannot determine which input sets
+            # need to be built. We refuse to do anything by returning
+            # an empty list.
+            if casr.get_inputs() is None:
+                LOGGER.warn('assessor with empty inputs field, cannot build processor for session' + casr.label())
+                return list()
+
+        # Compare existing to the "to build" assessors in parameter_matrix
+        for casr in existing_assessors:
+            for pi, p in enumerate(parameter_matrix):
+                if casr.get_inputs() == p:
+                    # BDB  6/5/21 do we ever have more than one assessor
+                    #             with the same set of inputs?
+                    assessors[pi].append(casr)
 
         return list(zip(copy.deepcopy(parameter_matrix), assessors))
 
@@ -1478,6 +1490,8 @@ class SgpProcessor(Processor_v3):
 
         # Load the command text
         self.command = doc.get('command')
+        self.command_pre = doc.get('pre', None)
+        self.command_post = doc.get('post', None)
 
         # Set Inputs from Yaml
         inputs = doc.get('inputs')
