@@ -1394,9 +1394,10 @@ class ClusterTask(Task):
         # Move output file
         src = self.outlog_path()
         dst = self.upload_outlog_dir()
-        mkdirp(dst)
-        LOGGER.debug('moving outlog file from %s to %s' % (src, dst))
-        shutil.move(src, dst)
+        if os.path.exists(src):
+            mkdirp(dst)
+            LOGGER.debug('moving outlog file from %s to %s' % (src, dst))
+            shutil.move(src, dst)
 
         # Touch file for dax_upload that job failed
         res_dir = self.upload_dir
